<?xml version="1.0" ?><!DOCTYPE TS><TS language="uz@Latn" version="2.0">
<context>
    <name>AboutDialog</name>
    <message>
        <source> About Boomaga</source>
        <translation>Boomaga haqida</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Dastur haqida</translation>
    </message>
    <message>
        <source>Authors</source>
        <translation>Mualliflar</translation>
    </message>
    <message>
        <source>Thanks</source>
        <translation>Tashakkur</translation>
    </message>
    <message>
        <source>Translations</source>
        <translation>Tarjimalar</translation>
    </message>
    <message>
        <source>Version: %1</source>
        <translation>Versiya: %1</translation>
    </message>
    <message>
        <source>Boomaga provides a virtual printer for CUPS. This can be used for print preview or for print booklets.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Copyright: %1-%2 %3</source>
        <translation>Mualliflik huquqi: %1-%2 %3</translation>
    </message>
    <message>
        <source>Homepage: %1</source>
        <translation>Uy sahifasi: %1</translation>
    </message>
    <message>
        <source>License: %1</source>
        <translation>Litsenziya: %1</translation>
    </message>
    <message>
        <source>Boomaga is developed by the &lt;a %1&gt;Boomaga Team and contributors&lt;/a&gt; on Github.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>If you are interested in working with our development team, &lt;a %1&gt;join us&lt;/a&gt;.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Special thanks to:</source>
        <translation>Alohida tashakkur:</translation>
    </message>
    <message>
        <source>If you want to help translate, we will be glad to see you in our translation team on &lt;a %1&gt;Transifex server&lt;/a&gt;.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ConfigDialog</name>
    <message>
        <source>Preferences</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Divide your long booklets into smaller sub-booklets for printing.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Print as sub-booklets</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Maximum number of sheets in your sub-booklet.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Sheets per sub-booklet:</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ExportToPdf</name>
    <message>
        <source>Print to PDF</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>File name</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Output file:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Meta info</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Author:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source> The name of the person who created the document.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Title:</source>
        <translation type="unfinished"/>
    </message>
    <message utf8="true">
        <source> The document’s title.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Subject:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source> The subject of the document.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source> Keywords associated with the document.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Keywords:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>PDF files (*.pdf);;All files (*.*)</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Overwrite file?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>A file named &quot;%1&quot; already exists.
Are you sure you want to overwrite it?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source> The document&apos;s title.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>JobsListView</name>
    <message>
        <source>( %1 pages )</source>
        <translation>( %1 sahifalar )</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Fayl</translation>
    </message>
    <message>
        <source>&amp;Preferences</source>
        <translation>&amp;Sozlashlar</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Yordam</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Parametrlar</translation>
    </message>
    <message>
        <source>Layout</source>
        <translation>joylashuv</translation>
    </message>
    <message>
        <source>1 up</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>2 up</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Booklet</source>
        <translation>Buklet</translation>
    </message>
    <message>
        <source>Print on both sides of a sheet.</source>
        <comment>MainForm::Double-sided checkbox tooltip</comment>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Double-sided</source>
        <comment>MainForm::Double-sided checkbox</comment>
        <translation>Ikki yoqlama</translation>
    </message>
    <message>
        <source>Jobs</source>
        <translation>Vazifalar</translation>
    </message>
    <message>
        <source>Printer</source>
        <translation>Printer</translation>
    </message>
    <message>
        <source>Configure...</source>
        <translation>Sozlash...</translation>
    </message>
    <message>
        <source>Toolbar</source>
        <translation>Asboblar paneli</translation>
    </message>
    <message>
        <source>&amp;Print</source>
        <translation>Cho&amp;p etish</translation>
    </message>
    <message>
        <source>E&amp;xit</source>
        <translation>&amp;Chiqish</translation>
    </message>
    <message>
        <source>Print and Close</source>
        <translation>Chop etish va yopish</translation>
    </message>
    <message>
        <source>Ctrl+P</source>
        <translation>Ctrl+P</translation>
    </message>
    <message>
        <source>Next sheet</source>
        <translation>Keyingi varaq</translation>
    </message>
    <message>
        <source>Previous sheet</source>
        <translation>Oldingi varaq</translation>
    </message>
    <message>
        <source>About Boomaga</source>
        <translation>Boomaga haqida</translation>
    </message>
    <message>
        <source>Boomaga</source>
        <translation>Boomaga</translation>
    </message>
    <message>
        <source>%v of %m</source>
        <comment>Format for QProgressBar (http://qt-project.org/doc/qt-4.8/qprogressbar.html#format-prop)</comment>
        <translation>%v %m&apos;dan</translation>
    </message>
    <message>
        <source>Print the all pages on %1.</source>
        <translation>Hamma sahifalarni %1&apos;da chop etish.</translation>
    </message>
    <message>
        <source>Print the odd pages on %1.&lt;p&gt;When finished, turn the pages, insert them into the printer&lt;br&gt;and click the Continue button.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Print the even pages on %1.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Continue</source>
        <translation>Davom ettirish</translation>
    </message>
    <message>
        <source>%1 pages</source>
        <comment>Status bar</comment>
        <translation>%1 sahifa</translation>
    </message>
    <message>
        <source>%1 page</source>
        <comment>Status bar</comment>
        <translation>%1 sahifa</translation>
    </message>
    <message>
        <source>%1 sheets</source>
        <comment>Status bar</comment>
        <translation>%1 varaq</translation>
    </message>
    <message>
        <source>%1 sheet</source>
        <comment>Status bar</comment>
        <translation>%1 varaq</translation>
    </message>
    <message>
        <source>Sheet %1 of %2</source>
        <comment>Status bar</comment>
        <translation>Varaq %1 %2&apos;dan</translation>
    </message>
    <message>
        <source>Insert blank page after this page</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Delete this page</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Undo delete</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Insert blank page before this page</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Delete pages until the end of the job.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Save</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Save project</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Ctrl+S</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Save as...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Save project under a new name</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Ctrl+Shift+S</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Open...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Open an existing project</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Ctrl+O</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Page %1</source>
        <comment>'Undo deletion' menu item</comment>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Boomaga files (*.boo);;All files (*.*)</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Project saved successfully.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>All supported files (*.pdf *.boo);;Boomaga files (*.boo);;PDF files (*.pdf);;All files (*.*)</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>4 up horizontal</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>4 up vertical</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>8 up horizontal</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>8 up vertical</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Start new booklet from this page</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Don&apos;t start new booklet from this page</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Rotate page to the left</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Rotate page to the right</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Rename job</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Rotate job to the left</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Rotate job to the right</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Delete job</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Job title:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&amp;Export...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Export the project to PDF</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Ctrl+E</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Clone job...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Clone job</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Number of copies:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Print with options...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Select number of copies before printing.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Ctrl+Shift+P</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>PrintDialog</name>
    <message>
        <source>Print document</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Number of copies:</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>PrinterSettings</name>
    <message>
        <source>Margins (mm)</source>
        <translation>Chegaralar (mm)</translation>
    </message>
    <message>
        <source>Right:</source>
        <translation>O&apos;ng:</translation>
    </message>
    <message>
        <source>Bottom:</source>
        <translation>Ost:</translation>
    </message>
    <message>
        <source>Internal:</source>
        <translation>Ichki:</translation>
    </message>
    <message>
        <source>Left:</source>
        <translation>Chap:</translation>
    </message>
    <message>
        <source>Top:</source>
        <translation>Tepa:</translation>
    </message>
    <message>
        <source>Duplex:</source>
        <translation>Dupleks:</translation>
    </message>
    <message>
        <source>Draw border</source>
        <translation>Chegara chizish</translation>
    </message>
    <message>
        <source>Print in reverse order</source>
        <translation>Teskari tartibda chop etish</translation>
    </message>
    <message>
        <source>Printer has duplexer</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Manual with reverse (suitable for most printers)</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Manual without reverse</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Preferences of &quot;%1&quot;</source>
        <translation>&quot;%1&quot; sozlashlari</translation>
    </message>
    <message>
        <source>Profiles</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>+</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>-</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Reset to default</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Profile %1</source>
        <comment>Defaul name for created printer profile in the Printer Settings diaog</comment>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Project</name>
    <message>
        <source>Boomaga</source>
        <comment>Error message title</comment>
        <translation>Boomaga</translation>
    </message>
    <message>
        <source>I can&apos;t write to file &apos;%1&apos;</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ProjectFile</name>
    <message>
        <source>I can&apos;t open file &quot;%1&quot; (No such file or directory)</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>I can&apos;t open file &quot;%1&quot; (Access denied)</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>I can&apos;t open file &quot;%1&quot;</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>I can&apos;t write to file &apos;%1&apos;</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>I can&apos;t read file &quot;%1&quot; because is either not a supported file type or because the file has been damaged.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>PDF file &quot;%1&quot; is damaged.</source>
        <translation>&quot;%1&quot; PDF fayli buzilgan.</translation>
    </message>
    <message>
        <source>PDF file &quot;%1&quot; is encripted.</source>
        <translation>&quot;%1&quot; PDF fayli shifrlangan.</translation>
    </message>
    <message>
        <source>I can&apos;t open file &quot;%1&quot;</source>
        <translation>&apos;%1&apos; faylini ochib bo&apos;lmadi</translation>
    </message>
    <message>
        <source>Print to file (PDF)</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>I can&apos;t read from file &apos;%1&apos;</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>I can&apos;t write to file &apos;%1&apos;</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Untitled</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Default</source>
        <comment>Printer profile default name</comment>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Settings</name>
    <message>
        <source>~/Untitled.pdf</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>TmpPdfFile</name>
    <message>
        <source>I can&apos;t create temporary file &quot;%1&quot;</source>
        <translation>&quot;%1&quot; vaqtinchalik faylini yaratib bo&apos;lmadi</translation>
    </message>
    <message>
        <source>Something is wrong. I can't find boomagamerger program.
Please reinstall me.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>I can&apos;t read file &apos;%1&apos;</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>I can&apos;t write to file &apos;%1&apos;</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>